@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Authority::EditorsBuilder;
 {
-  $Koha::Contrib::Tamil::Authority::EditorsBuilder::VERSION = '0.028';
+  $Koha::Contrib::Tamil::Authority::EditorsBuilder::VERSION = '0.029';
 }
 use Moose;
 
@@ -47,7 +47,7 @@ before 'run' => sub {
     my $sth = $self->koha->dbh->prepare(
         "SELECT biblionumber
            FROM biblioitems
-          WHERE biblionumber > 0 AND biblionumber < 200" );
+    ");
     $sth->execute;
     my @biblionumbers = ();
     while (my ($biblionumber) = $sth->fetchrow) {
@@ -144,6 +144,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =encoding UTF-8
@@ -154,7 +155,7 @@ Koha::Contrib::Tamil::Authority::EditorsBuilder
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 AUTHOR
 
@@ -169,4 +170,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
