@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Authority::LoadFileTask;
 {
-  $Koha::Contrib::Tamil::Authority::LoadFileTask::VERSION = '0.028';
+  $Koha::Contrib::Tamil::Authority::LoadFileTask::VERSION = '0.029';
 }
 # ABSTRACT: Task loading authorities into a Koha instance
 
@@ -93,10 +93,11 @@ sub process {
     my $self = shift;
     my $fh = $self->fh;
 
-    if ( defined($_ = <$fh>) ) {
+    my $line = <$fh>; 
+    if ( defined($line) ) {
         $self->SUPER::process();
-        chop;
-        my ($authcode, $sub) = /(\w+)\t(.*)/;
+        chop $line;
+        my ($authcode, $sub) = $line =~ /(\w+)\t(.*)/;
         my (@subfields) = split /\t|\|/, $sub; 
         #print "auth_code => $sub\n";
         #print "tbl : ", @subfields, "\n";
@@ -130,6 +131,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =encoding UTF-8
@@ -140,7 +142,7 @@ Koha::Contrib::Tamil::Authority::LoadFileTask - Task loading authorities into a
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 AUTHOR
 
@@ -155,4 +157,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
